@@ -9,6 +9,12 @@
 #' @param quit.legend \code{logical} indicating if legend of the third plot should be removed. By default is \code{FALSE}
 #' @param output \code{numeric} or {character} specifying the output neuron or output name to be plotted.
 #' By default is the first output (\code{output = 1}).
+#' @param plot_type \code{character} indicating which of the 3 plots to show. Useful when several variables are analyzed.
+#' Acceptable values are 'mean_sd', 'square', 'raw' corresponding to first, second and third plot respectively. If \code{NULL},
+#' all plots are shown at the same time. By default is \code{NULL}.
+#' @param inp_var \code{character} indicating which input variable to show in density plot. Only useful when
+#' choosing plot_type='raw' to show the density plot of one input variable. If \code{NULL}, all variables
+#' are plotted in density plot. By default is \code{NULL}.
 #' @return List with the following plot for each output: \itemize{ \item Plot 1: colorful plot with the
 #'   classification of the classes in a 2D map \item Plot 2: b/w plot with
 #'   probability of the chosen class in a 2D map \item Plot 3: plot with the
@@ -57,7 +63,8 @@
 #' @export SensitivityPlots
 SensitivityPlots <- function(sens = NULL, der = TRUE,
                              zoom = TRUE, quit.legend = FALSE,
-                             output = 1) {
+                             output = 1, plot_type=NULL,
+                             inp_var=NULL) {
   if (is.array(der)) stop("der argument is no more the raw sensitivities due to creation of SensMLP class. Check ?SensitivityPlots for more information")
   if (is.HessMLP(sens)) {
     sens <- HessToSensMLP(sens)
@@ -93,7 +100,12 @@ SensitivityPlots <- function(sens = NULL, der = TRUE,
       names(der2) <- dimnames(raw_sens)[[2]]
       # Remove any variable which is all zero -> pruned variable
       der2 <- der2[,!sapply(der2,function(x){all(x ==  0)})]
-      dataplot <- reshape2::melt(der2, measure.vars = names(der2))
+      if (!is.null(inp_var)) {
+        inp_var <- match.arg(inp_var, names(der2), several.ok = TRUE)
+      } else {
+        inp_var <- names(der2)
+      }
+      dataplot <- reshape2::melt(der2, measure.vars = inp_var)
 
       plotlist[[3]] <- ggplot2::ggplot(dataplot) +
         ggplot2::geom_density(ggplot2::aes_string(x = "value", fill = "variable", color = "variable"),
@@ -146,10 +158,27 @@ SensitivityPlots <- function(sens = NULL, der = TRUE,
     }
     pl[[out]] <- plotlist
   }
+  if (!is.null(plot_type)) {
+    plot_type <- match.arg(plot_type, c('mean_sd', 'square', 'raw'), several.ok = TRUE)
+    plot_number <- c()
+    if ('mean_sd' %in% plot_type) {
+      plot_number <- c(plot_number, 1)
+    }
+    if ('square' %in% plot_type) {
+      plot_number <- c(plot_number, 2)
+    }
+    if ('raw' %in% plot_type) {
+      plot_number <- c(plot_number, 3)
+    }
+  } else {
+    plot_number <- c(1, 2, 3)
+  }
   # Plot the list of plots created before
-  gridExtra::grid.arrange(grobs = pl[[ifelse(is.character(output), which(output == names(sens_orig$sens)), output)]],
-                          nrow  = length(plotlist),
+  gridExtra::grid.arrange(grobs = pl[[ifelse(is.character(output), which(output == names(sens_orig$sens)), output)]][plot_number],
+                          nrow  = length(plot_number),
                           ncols = 1)
   # Return the plots created if the user want to edit them by hand
   return(invisible(plotlist))
 }
+
+
